CitrusEnforcer class final

Inheritance
  • Object
  • Concept
  • EntryPoint
  • Separate
  • Module
  • CitrusEnforcer

Constructors

CitrusEnforcer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(Danger<Object, Exception> danger, bool flag, Log log) String
すべての log を含めるか, 最終的な結果だけを返すかを分岐.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recieveArguments(List<String> arguments) Future<String>
recieveRequest(CitrusRequest request) → FutureDanger<Object, Exception>
thenEnumerateRequest(EnumerateRequest request) → FutureDanger<Object, Exception>
thenGenerateRequest(GenerateRequest request) → FutureDanger<Object, Exception>
thenVersionRequest(VersionRequest request) → FutureSuccess<Object, Exception>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited