CitrusArray class sealed

Inheritance
Implementers

Constructors

CitrusArray.fromChain(VarietyEnumeration chain)
すべての要素が 有効な chain source であり head.name が object である場合 CitrusObjectArray を返す.
それ以外は CitrusTextArray を返す
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Iterable<CitrusArrayable>
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited