CitrusLanguage class sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compileFinish(
CitrusSymbolTable symbolTable, FileSystemModelList< FileSystemModel> fileSystemModelList, String generateLocation, ObjectDefinitionRoster objectDefinitionRoster) → Danger<FileSystemModelList< FileSystemModel> , CitrusLanguageException> -
compileFrame(
CitrusSymbolTable symbolTable, TemplateFileSetting templateFileSetting) → Danger< FileSystemModelList< FileSystemModel> , CitrusLanguageException>