CitrusSymbol class sealed

citrus で利用できる 特殊な変数.

Mixed-in types
  • AggregationPattern
  • EntityPattern<String>
Implementers

Constructors

CitrusSymbol.fromChain(Body chain)
chain is Flag then return FlagSymbol.
chain is Variety and chain として有効かつ Head.name is 'object' then return ObjectSymbol.
chain is Variety and ObjectSymbolの要件を満たさない then return TextSymbol.
chain is Variety and ObjectSymbolの要件を満たさない then return TextSymbol.
chain is VarietyEnumeration and すべての要素が 有効な chain source であり head.name が object である場合 CitrusObjectArray を返す.
それ以外は CitrusTextArray を返す
factory

Properties

hashCode int
properties に依存.
no setterinherited
name String
no setter
primaryKey String
no setteroverride
properties Map<String, Object>
inactivate(), = operator, [] operator, など に依存されている.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value CitrusSymbolValue
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInactivatedJson() Map<String, dynamic>
test 時に 等価比較が行えるように 一部の property 値を無効化する(一定の値に変更する)処理を加えた json を出力する.
例えば process id など, system によって割り振られる値をこちらで指定できないので このような場合に利用する.
inherited
toJson() Map<String, dynamic>
ここでの toJson とは json へ encode 可能な形式へ変換するという意味で使われる.
つまり json string を返すというわけではない.
また serialize としても利用するため deserialize 可能でなければならない.
inherited
toNestedStructureMap() Map<String, Object>
条件分岐で利用するため用意した.
inherited
toString() String
properties に依存.
inherited

Operators

operator ==(Object other) bool
instance properties の toString() をそれぞれ比較し合う。 properties, [] operator に依存.
inherited
operator [](String key) Object
properties から、operator == の内容を自動更新できるようにするために定義している.
inherited