TemporarySymbolLaps class final

laps loop index laps%length(2) 1 1 0
2 2 1 0 3 1 0 1 4 2 1 0 5 1 0 1 6 2 1 0 7 1 0 1 8 2 1 0

laps loop index laps%length(3) 1 1 0
2 2 1
3 3 2 0 4 1 0 1 5 2 1 2 6 3 2 0 7 1 0 1 8 2 1 2 9 3 2 0

laps が 0始まりの場合 laps loop index laps%length(2) 0 1 0
1 2 1
2 1 0 0 3 2 1 1 4 1 0 0 5 2 1 1 6 1 0 0 7 2 1 1 iterable symbol に紐づけられた値を取り出すのに必要な数字. 必ず 0 以上の 整数であること.

classification class.

Mixed-in types
  • ValuePattern<int>

Constructors

TemporarySymbolLaps(int value)
iterable symbol に紐づけられた値を取り出すのに必要な数字. 必ず 0 以上の 整数であること.
const
TemporarySymbolLaps.one()
const
TemporarySymbolLaps.zero()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
properties Map<String, Object>
inactivate(), = operator, [] operator, など に依存されている.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

increment() TemporarySymbolLaps
safety method.
1 が加算される.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
ここでの toJson とは json へ encode 可能な形式へ変換するという意味で使われる.
つまり json string を返すというわけではない.
また serialize としても利用するため deserialize 可能でなければならない.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
runtimeType and toString() are compared.
inherited