CitrusEnforcer class final
- Inheritance
-
- Object
- Concept
- EntryPoint
- Separate
- Module
- CitrusEnforcer
Constructors
- CitrusEnforcer()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recieveArguments(
List< String> arguments) → Future<CitrusResponse> -
recieveRequest(
CitrusRequest request) → Future< CitrusResponse> -
thenEnumerateRequest(
EnumerateRequest request) → Future< CitrusResponse> -
thenGenerateRequest(
GenerateRequest request) → Future< CitrusResponse> -
thenVersionRequest(
VersionRequest request) → Future< CitrusResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited